@@ -27,15 +27,24 @@ for to log, configure and control the run-time of your GUI app via command line
 application events
 ------------------
 
-The following application events are fired exactly one time in the lifetime of an app instance in the following order:
+The following application events are fired exactly one time at startup:
 
-* `on_app_init`: fired **after** :class:`ConsoleApp`-parts of the app instance got initialized (detected config files)
+* `on_app_init`: fired **after** :class:`ConsoleApp` app instance got initialized (detected config files)
   and **before** the image and sound resources and app states get loaded and the GUI framework app class instance gets
   initialized.
 * `on_app_start`: fired **after** the call of the method :meth:`~MainAppBase.run_app` and **before** the command line
-  options got parsed.
+  options get parsed.
 * `on_app_run`: fired **after** the parsing of the command line arguments and options and **before** the framework event
   loop of the used GUI framework gets started.
+
+.. hint::
+    Depending on the used gui framework there can be more app start events. E.g. the :mod:`ae.kivy_app` module fires the
+    events `on_app_build`, `on_app_built` and `on_app_started` (all of them fired after `on_app_run`). See also
+    :ref:`kivy app class events`.
+
+
+When an application gets stopped then the following events get fired in the following order:
+
 * `on_app_stop`: fired **after** the call of the method :meth:`~MainAppBase.stop_app` and **before** the framework win
   will be closed.
 * `on_app_exit`: fired **after* framework win got closed and just **before** the event loop of the GUI framework will be
@@ -47,6 +56,10 @@ The following application events are fired exactly one time in the lifetime of a
     The `on_app_stop` and `on_app_exit` events will only be fired if the app is explicitly calling the
     :meth:`~MainAppBase.stop_app` method.
 
+.. hint::
+    Depending on the used gui framework there can be more events. E.g. the :mod:`ae.kivy_app` module fires the event
+    `on_app_stopped` (before `on_app_stop` respectively `on_app_quit`).
+
 
 application status
 ------------------
@@ -312,21 +325,23 @@ optional configuration and extension
 Most of the base implementation helper methods can be overwritten by either the inheriting framework portion or directly
 by user main app class.
 """
-from abc import ABC, abstractmethod
+import os
 import re
+
+from abc import ABC, abstractmethod
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type
 
-from ae.base import NAME_PARTS_SEP, snake_to_camel                  # type: ignore
-from ae.updater import check_all                                    # type: ignore
-from ae.inspector import stack_var                                  # type: ignore
-from ae.files import FilesRegister, RegisteredFile                  # type: ignore
-from ae.i18n import default_language                                # type: ignore
-from ae.core import DEBUG_LEVELS                                    # type: ignore
-from ae.console import ConsoleApp                                   # type: ignore
+from ae.base import NAME_PARTS_SEP, snake_to_camel                                      # type: ignore
+from ae.updater import check_all                                                        # type: ignore
+from ae.inspector import stack_var                                                      # type: ignore
+from ae.files import FilesRegister, RegisteredFile                                      # type: ignore
+from ae.i18n import default_language, load_language_texts                               # type: ignore
+from ae.core import DEBUG_LEVELS                                                        # type: ignore
+from ae.console import ConsoleApp                                                       # type: ignore
 
 
-__version__ = '0.1.46'
+__version__ = '0.1.48'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -337,9 +352,6 @@ APP_STATE_SECTION_NAME = 'aeAppState'           #: config section name for to st
 APP_STATE_VERSION_VAR_NAME = 'app_state_version'
 APP_STATE_CURRENT_VERSION: int = 3              #: current application state version
 
-MIN_FONT_SIZE = 15.0                            #: minimum font size in pixels
-MAX_FONT_SIZE = 99.0                            #: maximum font size in pixels
-
 COLOR_BLACK = (0.009, 0.006, 0.003, 1.0)        # for to differentiate from framework pure black/white colors
 COLOR_WHITE = (0.999, 0.996, 0.993, 1.0)
 THEME_DARK_BACKGROUND_COLOR = COLOR_BLACK       #: dark theme background color in rgba(0.0 ... 1.0)
@@ -347,18 +359,27 @@ THEME_DARK_FONT_COLOR = COLOR_WHITE             #: dark theme font color in rgba
 THEME_LIGHT_BACKGROUND_COLOR = COLOR_WHITE      #: light theme background color in rgba(0.0 ... 1.0)
 THEME_LIGHT_FONT_COLOR = COLOR_BLACK            #: light theme font color in rgba(0.0 ... 1.0)
 
+MIN_FONT_SIZE = 15.0                            #: minimum font size in pixels
+MAX_FONT_SIZE = 99.0                            #: maximum font size in pixels
 
-check_all()     # let ae_updater module check/install any outstanding updates or new app versions
-
-
-FLOW_KEY_SEP = ':'
-
-FLOW_ACTION_RE = re.compile("[a-z0-9]+")
-FLOW_OBJECT_RE = re.compile("[A-Za-z0-9_]+")
 
 ACTIONS_EXTENDING_FLOW_PATH = ['add', 'confirm', 'edit', 'enter', 'open', 'show', 'suggest']
+""" flow actions that are extending the flow path. """
 ACTIONS_REDUCING_FLOW_PATH = ['close', 'leave']
+""" flow actions that are shrinking/reducing the flow paths. """
 ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION = ['', 'enter', 'focus', 'leave', 'suggest']
+""" flow actions that are processed without the need to be confirmed. """
+FLOW_KEY_SEP = ':'                              #: separator character between flow action/object and flow key
+
+FLOW_ACTION_RE = re.compile("[a-z0-9]+")        #: regular expression detecting invalid characters in flow action string
+FLOW_OBJECT_RE = re.compile("[A-Za-z0-9_]+")    #: regular expression detecting invalid characters in flow object string
+
+
+FOUND_IMAGES = FilesRegister()                  #: register of image files found in portions/packages at import time
+FOUND_SOUNDS = FilesRegister()                  #: register of sound files found in portions/packages at import time
+
+
+check_all()     # let ae_updater module check/install any outstanding updates or new app versions
 
 
 def id_of_flow(action: str, obj: str = "", key: str = "") -> str:
@@ -444,6 +465,24 @@ def flow_popup_class_name(flow_id: str) -> str:
     return f'{snake_to_camel(obj)}{action.capitalize()}Popup'
 
 
+def register_package_images():              # pragma: no cover
+    """ call from module scope of the package for to register/add image/img resources path. """
+    global FOUND_IMAGES
+
+    package_path = os.path.abspath(os.path.dirname(stack_var('__file__')))
+    search_path = os.path.join(package_path, 'img/**')
+    FOUND_IMAGES.add_path(search_path)
+
+
+def register_package_sounds():              # pragma: no cover
+    """ call from module scope of the package for to register/add sound file resources. """
+    global FOUND_SOUNDS
+
+    package_path = os.path.abspath(os.path.dirname(stack_var('__file__')))
+    search_path = os.path.join(package_path, 'snd/**')
+    FOUND_SOUNDS.add_path(search_path)
+
+
 def replace_flow_action(flow_id: str, new_action: str):
     """ replace action in given flow id.
 
@@ -578,30 +617,27 @@ class MainAppBase(ConsoleApp, ABC):
         """ default/fallback flow change confirmation event handler. """
         self.vpo("MainAppBase.on_app_quit default/fallback flow change confirmation event handler called")
 
-    def on_debug_level_change(self, debug_level: str, _event_kwargs: Dict[str, Any]) -> bool:
+    def on_debug_level_change(self, level_name: str, _event_kwargs: Dict[str, Any]) -> bool:
         """ debug level app state change flow change confirmation event handler.
 
-        :param debug_level:     the new debug level name to be set (passed as flow key).
+        :param level_name:      the new debug level name to be set (passed as flow key).
         :param _event_kwargs:   unused event kwargs.
         :return:                True for to confirm the debug level change.
         """
-        level = next(num for num, name in DEBUG_LEVELS.items() if name == debug_level)
-        self.vpo(f"MainAppBase.on_debug_level_change to {debug_level} -> {level}")
-        self.set_opt('debug_level', level)
+        debug_level = next(num for num, name in DEBUG_LEVELS.items() if name == level_name)
+        self.vpo(f"MainAppBase.on_debug_level_change to {level_name} -> {debug_level}")
+        self.set_opt('debug_level', debug_level)
         return True
 
     def on_lang_code_change(self, lang_code: str, _event_kwargs: Dict[str, Any]) -> bool:
         """ language app state change flow change confirmation event handler.
 
-        :param lang_code:       the new language code to be set (passed as flow key).
+        :param lang_code:       the new language code to be set (passed as flow key). Empty on first app run/start.
         :param _event_kwargs:   unused event kwargs.
         :return:                True for to confirm the language change.
         """
         self.vpo(f"MainAppBase.on_lang_code_change to {lang_code}")
-        self.change_app_state('lang_code', lang_code)
-        if lang_code:
-            default_language(lang_code)
-            self.set_var('lang_code', lang_code, section=APP_STATE_SECTION_NAME)  # add optional app state var to config
+        self.load_translations(lang_code)
         return True
 
     def on_light_theme_change(self, _flow_key: str, event_kwargs: Dict[str, Any]) -> bool:
@@ -960,11 +996,32 @@ class MainAppBase(ConsoleApp, ABC):
 
     def load_images(self):
         """ load images from app folder img. """
-        self.image_files = FilesRegister('img/**')
+        file_reg = FilesRegister()
+        file_reg.add_path('img/**')
+        file_reg.add_files_register(FOUND_IMAGES)
+        self.image_files = file_reg
 
     def load_sounds(self):
         """ load audio sounds from app folder snd. """
-        self.sound_files = FilesRegister('snd/**')
+        file_reg = FilesRegister()
+        file_reg.add_path('snd/**')
+        file_reg.add_files_register(FOUND_SOUNDS)
+        self.sound_files = file_reg
+
+    def load_translations(self, lang_code: str):
+        """ load translation texts for the passed language code.
+
+        :param lang_code:       the new language code to be set (passed as flow key). Empty on first app run/start.
+        """
+        is_empty = not lang_code
+        old_lang = self.lang_code
+
+        lang_code = load_language_texts(lang_code)
+        self.change_app_state('lang_code', lang_code)
+
+        if is_empty or lang_code != old_lang:
+            default_language(lang_code)
+            self.set_var('lang_code', lang_code, section=APP_STATE_SECTION_NAME)  # add optional app state var to config
 
     def play_beep(self):
         """ make a short beep sound, should be overwritten by GUI framework. """
